@@ -14,11 +14,11 @@ class AttachKeyPairsAction(BaseAction):
 
         parser.add_argument('-i', '--instances', dest='instances',
                 action='store', type=str, default='',
-                help='The IDs of instances the keypairs will be attached to.')
+                help='the IDs of instances the keypairs will be attached to.')
 
         parser.add_argument('-k', '--keypairs', dest='keypairs',
                 action='store', type=str, default='',
-                help='The comma separated IDs of keypairs you want to attach to instances. ')
+                help='the comma separated IDs of keypairs you want to attach to instances. ')
       
     @classmethod
     def build_directive(cls, options):
